@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
@@ -48,6 +38,13 @@ namespace Model
     t3a_large,
     t3a_xlarge,
     t3a_2xlarge,
+    t4g_nano,
+    t4g_micro,
+    t4g_small,
+    t4g_medium,
+    t4g_large,
+    t4g_xlarge,
+    t4g_2xlarge,
     m1_small,
     m1_medium,
     m1_large,
@@ -94,6 +91,15 @@ namespace Model
     r5a_12xlarge,
     r5a_16xlarge,
     r5a_24xlarge,
+    r5b_large,
+    r5b_xlarge,
+    r5b_2xlarge,
+    r5b_4xlarge,
+    r5b_8xlarge,
+    r5b_12xlarge,
+    r5b_16xlarge,
+    r5b_24xlarge,
+    r5b_metal,
     r5d_large,
     r5d_xlarge,
     r5d_2xlarge,
@@ -111,6 +117,24 @@ namespace Model
     r5ad_12xlarge,
     r5ad_16xlarge,
     r5ad_24xlarge,
+    r6g_metal,
+    r6g_medium,
+    r6g_large,
+    r6g_xlarge,
+    r6g_2xlarge,
+    r6g_4xlarge,
+    r6g_8xlarge,
+    r6g_12xlarge,
+    r6g_16xlarge,
+    r6gd_metal,
+    r6gd_medium,
+    r6gd_large,
+    r6gd_xlarge,
+    r6gd_2xlarge,
+    r6gd_4xlarge,
+    r6gd_8xlarge,
+    r6gd_12xlarge,
+    r6gd_16xlarge,
     x1_16xlarge,
     x1_32xlarge,
     x1e_xlarge,
@@ -161,6 +185,22 @@ namespace Model
     c5_18xlarge,
     c5_24xlarge,
     c5_metal,
+    c5a_large,
+    c5a_xlarge,
+    c5a_2xlarge,
+    c5a_4xlarge,
+    c5a_8xlarge,
+    c5a_12xlarge,
+    c5a_16xlarge,
+    c5a_24xlarge,
+    c5ad_large,
+    c5ad_xlarge,
+    c5ad_2xlarge,
+    c5ad_4xlarge,
+    c5ad_8xlarge,
+    c5ad_12xlarge,
+    c5ad_16xlarge,
+    c5ad_24xlarge,
     c5d_large,
     c5d_xlarge,
     c5d_2xlarge,
@@ -176,6 +216,33 @@ namespace Model
     c5n_4xlarge,
     c5n_9xlarge,
     c5n_18xlarge,
+    c5n_metal,
+    c6g_metal,
+    c6g_medium,
+    c6g_large,
+    c6g_xlarge,
+    c6g_2xlarge,
+    c6g_4xlarge,
+    c6g_8xlarge,
+    c6g_12xlarge,
+    c6g_16xlarge,
+    c6gd_metal,
+    c6gd_medium,
+    c6gd_large,
+    c6gd_xlarge,
+    c6gd_2xlarge,
+    c6gd_4xlarge,
+    c6gd_8xlarge,
+    c6gd_12xlarge,
+    c6gd_16xlarge,
+    c6gn_medium,
+    c6gn_large,
+    c6gn_xlarge,
+    c6gn_2xlarge,
+    c6gn_4xlarge,
+    c6gn_8xlarge,
+    c6gn_12xlarge,
+    c6gn_16xlarge,
     cc1_4xlarge,
     cc2_8xlarge,
     g2_2xlarge,
@@ -184,12 +251,16 @@ namespace Model
     g3_8xlarge,
     g3_16xlarge,
     g3s_xlarge,
+    g4ad_4xlarge,
+    g4ad_8xlarge,
+    g4ad_16xlarge,
     g4dn_xlarge,
     g4dn_2xlarge,
     g4dn_4xlarge,
     g4dn_8xlarge,
     g4dn_12xlarge,
     g4dn_16xlarge,
+    g4dn_metal,
     cg1_4xlarge,
     p2_xlarge,
     p2_8xlarge,
@@ -198,10 +269,21 @@ namespace Model
     p3_8xlarge,
     p3_16xlarge,
     p3dn_24xlarge,
+    p4d_24xlarge,
     d2_xlarge,
     d2_2xlarge,
     d2_4xlarge,
     d2_8xlarge,
+    d3_xlarge,
+    d3_2xlarge,
+    d3_4xlarge,
+    d3_8xlarge,
+    d3en_xlarge,
+    d3en_2xlarge,
+    d3en_4xlarge,
+    d3en_6xlarge,
+    d3en_8xlarge,
+    d3en_12xlarge,
     f1_2xlarge,
     f1_4xlarge,
     f1_16xlarge,
@@ -239,6 +321,13 @@ namespace Model
     m5ad_12xlarge,
     m5ad_16xlarge,
     m5ad_24xlarge,
+    m5zn_large,
+    m5zn_xlarge,
+    m5zn_2xlarge,
+    m5zn_3xlarge,
+    m5zn_6xlarge,
+    m5zn_12xlarge,
+    m5zn_metal,
     h1_2xlarge,
     h1_4xlarge,
     h1_8xlarge,
@@ -305,7 +394,17 @@ namespace Model
     m6g_4xlarge,
     m6g_8xlarge,
     m6g_12xlarge,
-    m6g_16xlarge
+    m6g_16xlarge,
+    m6gd_metal,
+    m6gd_medium,
+    m6gd_large,
+    m6gd_xlarge,
+    m6gd_2xlarge,
+    m6gd_4xlarge,
+    m6gd_8xlarge,
+    m6gd_12xlarge,
+    m6gd_16xlarge,
+    mac1_metal
   };
 
 namespace InstanceTypeMapper
