@@ -112,63 +112,75 @@ namespace Model
 
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline const Aws::String& GetPrivateDnsName() const{ return m_privateDnsName; }
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline bool PrivateDnsNameHasBeenSet() const { return m_privateDnsNameHasBeenSet; }
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline void SetPrivateDnsName(const Aws::String& value) { m_privateDnsNameHasBeenSet = true; m_privateDnsName = value; }
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline void SetPrivateDnsName(Aws::String&& value) { m_privateDnsNameHasBeenSet = true; m_privateDnsName = std::move(value); }
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline void SetPrivateDnsName(const char* value) { m_privateDnsNameHasBeenSet = true; m_privateDnsName.assign(value); }
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline ModifyVpcEndpointServiceConfigurationRequest& WithPrivateDnsName(const Aws::String& value) { SetPrivateDnsName(value); return *this;}
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline ModifyVpcEndpointServiceConfigurationRequest& WithPrivateDnsName(Aws::String&& value) { SetPrivateDnsName(std::move(value)); return *this;}
 
     /**
-     * <p>The private DNS name to assign to the endpoint service.</p>
+     * <p>(Interface endpoint configuration) The private DNS name to assign to the
+     * endpoint service.</p>
      */
     inline ModifyVpcEndpointServiceConfigurationRequest& WithPrivateDnsName(const char* value) { SetPrivateDnsName(value); return *this;}
 
 
     /**
-     * <p>Removes the private DNS name of the endpoint service.</p>
+     * <p>(Interface endpoint configuration) Removes the private DNS name of the
+     * endpoint service.</p>
      */
     inline bool GetRemovePrivateDnsName() const{ return m_removePrivateDnsName; }
 
     /**
-     * <p>Removes the private DNS name of the endpoint service.</p>
+     * <p>(Interface endpoint configuration) Removes the private DNS name of the
+     * endpoint service.</p>
      */
     inline bool RemovePrivateDnsNameHasBeenSet() const { return m_removePrivateDnsNameHasBeenSet; }
 
     /**
-     * <p>Removes the private DNS name of the endpoint service.</p>
+     * <p>(Interface endpoint configuration) Removes the private DNS name of the
+     * endpoint service.</p>
      */
     inline void SetRemovePrivateDnsName(bool value) { m_removePrivateDnsNameHasBeenSet = true; m_removePrivateDnsName = value; }
 
     /**
-     * <p>Removes the private DNS name of the endpoint service.</p>
+     * <p>(Interface endpoint configuration) Removes the private DNS name of the
+     * endpoint service.</p>
      */
     inline ModifyVpcEndpointServiceConfigurationRequest& WithRemovePrivateDnsName(bool value) { SetRemovePrivateDnsName(value); return *this;}
 
@@ -307,6 +319,116 @@ namespace Model
      */
     inline ModifyVpcEndpointServiceConfigurationRequest& AddRemoveNetworkLoadBalancerArns(const char* value) { m_removeNetworkLoadBalancerArnsHasBeenSet = true; m_removeNetworkLoadBalancerArns.push_back(value); return *this; }
 
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetAddGatewayLoadBalancerArns() const{ return m_addGatewayLoadBalancerArns; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline bool AddGatewayLoadBalancerArnsHasBeenSet() const { return m_addGatewayLoadBalancerArnsHasBeenSet; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline void SetAddGatewayLoadBalancerArns(const Aws::Vector<Aws::String>& value) { m_addGatewayLoadBalancerArnsHasBeenSet = true; m_addGatewayLoadBalancerArns = value; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline void SetAddGatewayLoadBalancerArns(Aws::Vector<Aws::String>&& value) { m_addGatewayLoadBalancerArnsHasBeenSet = true; m_addGatewayLoadBalancerArns = std::move(value); }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& WithAddGatewayLoadBalancerArns(const Aws::Vector<Aws::String>& value) { SetAddGatewayLoadBalancerArns(value); return *this;}
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& WithAddGatewayLoadBalancerArns(Aws::Vector<Aws::String>&& value) { SetAddGatewayLoadBalancerArns(std::move(value)); return *this;}
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddAddGatewayLoadBalancerArns(const Aws::String& value) { m_addGatewayLoadBalancerArnsHasBeenSet = true; m_addGatewayLoadBalancerArns.push_back(value); return *this; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddAddGatewayLoadBalancerArns(Aws::String&& value) { m_addGatewayLoadBalancerArnsHasBeenSet = true; m_addGatewayLoadBalancerArns.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your
+     * service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddAddGatewayLoadBalancerArns(const char* value) { m_addGatewayLoadBalancerArnsHasBeenSet = true; m_addGatewayLoadBalancerArns.push_back(value); return *this; }
+
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline const Aws::Vector<Aws::String>& GetRemoveGatewayLoadBalancerArns() const{ return m_removeGatewayLoadBalancerArns; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline bool RemoveGatewayLoadBalancerArnsHasBeenSet() const { return m_removeGatewayLoadBalancerArnsHasBeenSet; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline void SetRemoveGatewayLoadBalancerArns(const Aws::Vector<Aws::String>& value) { m_removeGatewayLoadBalancerArnsHasBeenSet = true; m_removeGatewayLoadBalancerArns = value; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline void SetRemoveGatewayLoadBalancerArns(Aws::Vector<Aws::String>&& value) { m_removeGatewayLoadBalancerArnsHasBeenSet = true; m_removeGatewayLoadBalancerArns = std::move(value); }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& WithRemoveGatewayLoadBalancerArns(const Aws::Vector<Aws::String>& value) { SetRemoveGatewayLoadBalancerArns(value); return *this;}
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& WithRemoveGatewayLoadBalancerArns(Aws::Vector<Aws::String>&& value) { SetRemoveGatewayLoadBalancerArns(std::move(value)); return *this;}
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddRemoveGatewayLoadBalancerArns(const Aws::String& value) { m_removeGatewayLoadBalancerArnsHasBeenSet = true; m_removeGatewayLoadBalancerArns.push_back(value); return *this; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddRemoveGatewayLoadBalancerArns(Aws::String&& value) { m_removeGatewayLoadBalancerArnsHasBeenSet = true; m_removeGatewayLoadBalancerArns.push_back(std::move(value)); return *this; }
+
+    /**
+     * <p>The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from
+     * your service configuration.</p>
+     */
+    inline ModifyVpcEndpointServiceConfigurationRequest& AddRemoveGatewayLoadBalancerArns(const char* value) { m_removeGatewayLoadBalancerArnsHasBeenSet = true; m_removeGatewayLoadBalancerArns.push_back(value); return *this; }
+
   private:
 
     bool m_dryRun;
@@ -329,6 +451,12 @@ namespace Model
 
     Aws::Vector<Aws::String> m_removeNetworkLoadBalancerArns;
     bool m_removeNetworkLoadBalancerArnsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_addGatewayLoadBalancerArns;
+    bool m_addGatewayLoadBalancerArnsHasBeenSet;
+
+    Aws::Vector<Aws::String> m_removeGatewayLoadBalancerArns;
+    bool m_removeGatewayLoadBalancerArnsHasBeenSet;
   };
 
 } // namespace Model
