@@ -1,23 +1,15 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSStreamFwd.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/ec2/model/EnaSupport.h>
+#include <aws/ec2/model/NetworkCardInfo.h>
 #include <utility>
 
 namespace Aws
@@ -52,42 +44,42 @@ namespace Model
 
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline const Aws::String& GetNetworkPerformance() const{ return m_networkPerformance; }
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline bool NetworkPerformanceHasBeenSet() const { return m_networkPerformanceHasBeenSet; }
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline void SetNetworkPerformance(const Aws::String& value) { m_networkPerformanceHasBeenSet = true; m_networkPerformance = value; }
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline void SetNetworkPerformance(Aws::String&& value) { m_networkPerformanceHasBeenSet = true; m_networkPerformance = std::move(value); }
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline void SetNetworkPerformance(const char* value) { m_networkPerformanceHasBeenSet = true; m_networkPerformance.assign(value); }
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline NetworkInfo& WithNetworkPerformance(const Aws::String& value) { SetNetworkPerformance(value); return *this;}
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline NetworkInfo& WithNetworkPerformance(Aws::String&& value) { SetNetworkPerformance(std::move(value)); return *this;}
 
     /**
-     * <p>Describes the network performance.</p>
+     * <p>The network performance.</p>
      */
     inline NetworkInfo& WithNetworkPerformance(const char* value) { SetNetworkPerformance(value); return *this;}
 
@@ -113,6 +105,93 @@ namespace Model
     inline NetworkInfo& WithMaximumNetworkInterfaces(int value) { SetMaximumNetworkInterfaces(value); return *this;}
 
 
+    /**
+     * <p>The maximum number of physical network cards that can be allocated to the
+     * instance.</p>
+     */
+    inline int GetMaximumNetworkCards() const{ return m_maximumNetworkCards; }
+
+    /**
+     * <p>The maximum number of physical network cards that can be allocated to the
+     * instance.</p>
+     */
+    inline bool MaximumNetworkCardsHasBeenSet() const { return m_maximumNetworkCardsHasBeenSet; }
+
+    /**
+     * <p>The maximum number of physical network cards that can be allocated to the
+     * instance.</p>
+     */
+    inline void SetMaximumNetworkCards(int value) { m_maximumNetworkCardsHasBeenSet = true; m_maximumNetworkCards = value; }
+
+    /**
+     * <p>The maximum number of physical network cards that can be allocated to the
+     * instance.</p>
+     */
+    inline NetworkInfo& WithMaximumNetworkCards(int value) { SetMaximumNetworkCards(value); return *this;}
+
+
+    /**
+     * <p>The index of the default network card, starting at 0.</p>
+     */
+    inline int GetDefaultNetworkCardIndex() const{ return m_defaultNetworkCardIndex; }
+
+    /**
+     * <p>The index of the default network card, starting at 0.</p>
+     */
+    inline bool DefaultNetworkCardIndexHasBeenSet() const { return m_defaultNetworkCardIndexHasBeenSet; }
+
+    /**
+     * <p>The index of the default network card, starting at 0.</p>
+     */
+    inline void SetDefaultNetworkCardIndex(int value) { m_defaultNetworkCardIndexHasBeenSet = true; m_defaultNetworkCardIndex = value; }
+
+    /**
+     * <p>The index of the default network card, starting at 0.</p>
+     */
+    inline NetworkInfo& WithDefaultNetworkCardIndex(int value) { SetDefaultNetworkCardIndex(value); return *this;}
+
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline const Aws::Vector<NetworkCardInfo>& GetNetworkCards() const{ return m_networkCards; }
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline bool NetworkCardsHasBeenSet() const { return m_networkCardsHasBeenSet; }
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline void SetNetworkCards(const Aws::Vector<NetworkCardInfo>& value) { m_networkCardsHasBeenSet = true; m_networkCards = value; }
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline void SetNetworkCards(Aws::Vector<NetworkCardInfo>&& value) { m_networkCardsHasBeenSet = true; m_networkCards = std::move(value); }
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline NetworkInfo& WithNetworkCards(const Aws::Vector<NetworkCardInfo>& value) { SetNetworkCards(value); return *this;}
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline NetworkInfo& WithNetworkCards(Aws::Vector<NetworkCardInfo>&& value) { SetNetworkCards(std::move(value)); return *this;}
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline NetworkInfo& AddNetworkCards(const NetworkCardInfo& value) { m_networkCardsHasBeenSet = true; m_networkCards.push_back(value); return *this; }
+
+    /**
+     * <p>Describes the network cards for the instance type.</p>
+     */
+    inline NetworkInfo& AddNetworkCards(NetworkCardInfo&& value) { m_networkCardsHasBeenSet = true; m_networkCards.push_back(std::move(value)); return *this; }
+
+
     /**
      * <p>The maximum number of IPv4 addresses per network interface.</p>
      */
@@ -235,6 +314,15 @@ namespace Model
     int m_maximumNetworkInterfaces;
     bool m_maximumNetworkInterfacesHasBeenSet;
 
+    int m_maximumNetworkCards;
+    bool m_maximumNetworkCardsHasBeenSet;
+
+    int m_defaultNetworkCardIndex;
+    bool m_defaultNetworkCardIndexHasBeenSet;
+
+    Aws::Vector<NetworkCardInfo> m_networkCards;
+    bool m_networkCardsHasBeenSet;
+
     int m_ipv4AddressesPerInterface;
     bool m_ipv4AddressesPerInterfaceHasBeenSet;
 
