@@ -208,6 +208,55 @@ namespace Model
     inline ReplaceRouteRequest& WithDryRun(bool value) { SetDryRun(value); return *this;}
 
 
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline const Aws::String& GetVpcEndpointId() const{ return m_vpcEndpointId; }
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline bool VpcEndpointIdHasBeenSet() const { return m_vpcEndpointIdHasBeenSet; }
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline void SetVpcEndpointId(const Aws::String& value) { m_vpcEndpointIdHasBeenSet = true; m_vpcEndpointId = value; }
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline void SetVpcEndpointId(Aws::String&& value) { m_vpcEndpointIdHasBeenSet = true; m_vpcEndpointId = std::move(value); }
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline void SetVpcEndpointId(const char* value) { m_vpcEndpointIdHasBeenSet = true; m_vpcEndpointId.assign(value); }
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline ReplaceRouteRequest& WithVpcEndpointId(const Aws::String& value) { SetVpcEndpointId(value); return *this;}
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline ReplaceRouteRequest& WithVpcEndpointId(Aws::String&& value) { SetVpcEndpointId(std::move(value)); return *this;}
+
+    /**
+     * <p>The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints
+     * only.</p>
+     */
+    inline ReplaceRouteRequest& WithVpcEndpointId(const char* value) { SetVpcEndpointId(value); return *this;}
+
+
     /**
      * <p>[IPv6 traffic only] The ID of an egress-only internet gateway.</p>
      */
@@ -656,6 +705,9 @@ namespace Model
     bool m_dryRun;
     bool m_dryRunHasBeenSet;
 
+    Aws::String m_vpcEndpointId;
+    bool m_vpcEndpointIdHasBeenSet;
+
     Aws::String m_egressOnlyInternetGatewayId;
     bool m_egressOnlyInternetGatewayIdHasBeenSet;
 
