@@ -1,17 +1,7 @@
-﻿/*
-* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-*
-* Licensed under the Apache License, Version 2.0 (the "License").
-* You may not use this file except in compliance with the License.
-* A copy of the License is located at
-*
-*  http://aws.amazon.com/apache2.0
-*
-* or in the "license" file accompanying this file. This file is distributed
-* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-* express or implied. See the License for the specific language governing
-* permissions and limitations under the License.
-*/
+﻿/**
+ * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+ * SPDX-License-Identifier: Apache-2.0.
+ */
 
 #pragma once
 #include <aws/s3/S3_EXPORTS.h>
@@ -52,6 +42,8 @@ namespace Model
 
     Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;
 
+    inline bool ShouldComputeContentMd5() const override { return true; }
+
 
     /**
      * <p>The canned ACL to apply to the bucket.</p>
@@ -166,7 +158,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline const Aws::String& GetContentMD5() const{ return m_contentMD5; }
 
@@ -174,7 +168,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline bool ContentMD5HasBeenSet() const { return m_contentMD5HasBeenSet; }
 
@@ -182,7 +178,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline void SetContentMD5(const Aws::String& value) { m_contentMD5HasBeenSet = true; m_contentMD5 = value; }
 
@@ -190,7 +188,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline void SetContentMD5(Aws::String&& value) { m_contentMD5HasBeenSet = true; m_contentMD5 = std::move(value); }
 
@@ -198,7 +198,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline void SetContentMD5(const char* value) { m_contentMD5HasBeenSet = true; m_contentMD5.assign(value); }
 
@@ -206,7 +208,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline PutBucketAclRequest& WithContentMD5(const Aws::String& value) { SetContentMD5(value); return *this;}
 
@@ -214,7 +218,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline PutBucketAclRequest& WithContentMD5(Aws::String&& value) { SetContentMD5(std::move(value)); return *this;}
 
@@ -222,7 +228,9 @@ namespace Model
      * <p>The base64-encoded 128-bit MD5 digest of the data. This header must be used
      * as a message integrity check to verify that the request body was not corrupted
      * in transit. For more information, go to <a
-     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p>
+     * href="http://www.ietf.org/rfc/rfc1864.txt">RFC 1864.</a> </p> <p>For requests
+     * made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is
+     * calculated automatically.</p>
      */
     inline PutBucketAclRequest& WithContentMD5(const char* value) { SetContentMD5(value); return *this;}
 
@@ -440,6 +448,63 @@ namespace Model
     inline PutBucketAclRequest& WithGrantWriteACP(const char* value) { SetGrantWriteACP(value); return *this;}
 
 
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline const Aws::String& GetExpectedBucketOwner() const{ return m_expectedBucketOwner; }
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline bool ExpectedBucketOwnerHasBeenSet() const { return m_expectedBucketOwnerHasBeenSet; }
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(const Aws::String& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = value; }
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(Aws::String&& value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner = std::move(value); }
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline void SetExpectedBucketOwner(const char* value) { m_expectedBucketOwnerHasBeenSet = true; m_expectedBucketOwner.assign(value); }
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline PutBucketAclRequest& WithExpectedBucketOwner(const Aws::String& value) { SetExpectedBucketOwner(value); return *this;}
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline PutBucketAclRequest& WithExpectedBucketOwner(Aws::String&& value) { SetExpectedBucketOwner(std::move(value)); return *this;}
+
+    /**
+     * <p>The account id of the expected bucket owner. If the bucket is owned by a
+     * different account, the request will fail with an HTTP <code>403 (Access
+     * Denied)</code> error.</p>
+     */
+    inline PutBucketAclRequest& WithExpectedBucketOwner(const char* value) { SetExpectedBucketOwner(value); return *this;}
+
+
     
     inline const Aws::Map<Aws::String, Aws::String>& GetCustomizedAccessLogTag() const{ return m_customizedAccessLogTag; }
 
@@ -508,6 +573,9 @@ namespace Model
     Aws::String m_grantWriteACP;
     bool m_grantWriteACPHasBeenSet;
 
+    Aws::String m_expectedBucketOwner;
+    bool m_expectedBucketOwnerHasBeenSet;
+
     Aws::Map<Aws::String, Aws::String> m_customizedAccessLogTag;
     bool m_customizedAccessLogTagHasBeenSet;
   };
